Module: Google::Cloud::PolicySimulator
- Defined in:
- lib/google/cloud/policy_simulator.rb,
lib/google/cloud/policy_simulator/version.rb
Constant Summary collapse
- VERSION =
"1.2.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.policy_simulator| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-policy_simulator library.
-
.simulator(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Simulator.
-
.simulator_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Simulator service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.policy_simulator| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-policy_simulator library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
157 158 159 160 161 |
# File 'lib/google/cloud/policy_simulator.rb', line 157 def self.configure yield ::Google::Cloud.configure.policy_simulator if block_given? ::Google::Cloud.configure.policy_simulator end |
.simulator(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Simulator.
By default, this returns an instance of
Google::Cloud::PolicySimulator::V1::Simulator::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the Simulator service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the Simulator service. You can determine whether the method will succeed by calling simulator_available?.
About Simulator
Policy Simulator API service.
Policy Simulator is a collection of endpoints for creating, running, and viewing a Replay. A Replay is a type of simulation that lets you see how your principals' access to resources might change if you changed your IAM policy.
During a Replay, Policy Simulator re-evaluates, or replays, past access attempts under both the current policy and your proposed policy, and compares those results to determine how your principals' access might change under the proposed policy.
86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/google/cloud/policy_simulator.rb', line 86 def self.simulator version: :v1, transport: :grpc, &block require "google/cloud/policy_simulator/#{version.to_s.downcase}" package_name = Google::Cloud::PolicySimulator .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::PolicySimulator.const_get(package_name).const_get(:Simulator) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.simulator_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Simulator service is supported by the current client. If true, you can retrieve a client object by calling simulator. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the Simulator service, or if the versioned client gem needs an update to support the Simulator service.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/google/cloud/policy_simulator.rb', line 110 def self.simulator_available? version: :v1, transport: :grpc require "google/cloud/policy_simulator/#{version.to_s.downcase}" package_name = Google::Cloud::PolicySimulator .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::PolicySimulator.const_get package_name return false unless service_module.const_defined? :Simulator service_module = service_module.const_get :Simulator if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |